# -*- coding: utf-8 -*-
def flatten(iterable, ignore=None):
    """Flatten nested iterable object
    Args:
        iterable_obejct (iterable) : required
        ignore (type or tuple) : optional
    Return:
        flattend (generator)

    >>> iterable = [(1, 2, 3), (4, (5, 6))]
    >>> list(flatten(iterable))
    [1, 2, 3, 4, 5, 6]
    >>> iterable = [('abc'), ('def', ('g', 'hi'))]
    >>> list(flatten(iterable, ignore=(str,)))
    ['abc', 'def', 'g', 'hi']
    """
    def _flatten(x, ignore):
        if hasattr(x, '__iter__'):
            if ignore and isinstance(x, ignore):
                yield x
            else:
                for y in x:
                    yield from _flatten(y, ignore)
        else:
            yield x

    for x in iterable:
        yield from _flatten(x, ignore)



# -*- coding: utf-8 -*-
"""Flati - Flatten nested iterable object

Author:
    Yukino Ikegami

Lisence:
    MIT License

Usage:
    >>> import flati
    >>> iterable = [(1, 2, 3), (4, (5, 6))]
    >>> list(flati.flatten(iterable))
    [1, 2, 3, 4, 5, 6]
    >>> iterable = [('abc'), ('def', ('g', 'hi'))]
    >>> list(flati.flatten(iterable, ignore=(str,)))
    ['abc', 'def', 'g', 'hi']
"""
from sys import version_info
if version_info < (3,):
    from . import py2
    flatten = py2.flatten
else:
    from . import py3
    flatten = py3.flatten

VERSION = (0, 1, 1)
__version__ = '0.1.1'



# -*- coding: utf-8 -*-
from codecs import open
import os
import re
from setuptools import setup

with open(os.path.join('flati', '__init__.py'), 'r', encoding='utf8') as f:
    version = re.compile(
        r".*__version__ = '(.*?)'", re.S).match(f.read()).group(1)

setup(
    name='flati',
    packages=['flati'],
    version=version,
    license='MIT License',
    platforms=['POSIX', 'Windows', 'Unix', 'MacOS'],
    description='Flatten nested iterable object',
    author='Yukino Ikegami',
    author_email='yknikgm@gmail.com',
    url='https://github.com/ikegami-yukino/flati',
    keywords=['flatten', 'generator'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS',
        'Operating System :: Microsoft',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    data_files=[('', ['README.rst', 'CHANGES.rst'])],
    long_description='%s\n\n%s' % (open('README.rst', encoding='utf8').read(),
                                   open('CHANGES.rst', encoding='utf8').read()),
    test_suite = 'nose.collector'
)
